@@ -1,8 +1,9 @@
 import os.path
 from configparser import DuplicateSectionError
-from typing import TypeAlias, Optional
+from typing import TypeAlias
 
-from aliot.core._config.constants import CONFIG_FILE_NAME, DEFAULT_FOLDER
+from aliot.core._config.constants import CONFIG_FILE_NAME, DEFAULT_FOLDER, DEFAULT_CONFIG_FILE_PATH
+from aliot.core._config.config import make_config_section, get_default_code
 from aliot.core._config.config import update_config, config_init, get_config
 
 result: TypeAlias = tuple[bool | None, str | None]
@@ -25,40 +26,30 @@ def make_obj(obj_name: str) -> result:
     path = f"{DEFAULT_FOLDER}/{obj_name}"
     if os.path.exists(path):
         return False, "Object already exists"
-    variable = obj_name.replace('-', '_')
     try:
         os.makedirs(path, exist_ok=True)
         with open(f"{path}/{obj_name}.py", "w+") as f:
-            f.write(
-                f"""from aliot.aliot_obj import AliotObj
-
-{variable} = AliotObj("{obj_name}")
-
-# write your code here
-
-{variable}.run()
-""")
+            f.write(get_default_code(obj_name))
     except FileNotFoundError:
         return None, f"Could not create object script at {path!r}"
 
     return True, None
 
 
-def make_obj_config(obj_name: str, obj_id: Optional[str] = None, *, force: bool = False) -> result:
-    config_path = f"{DEFAULT_FOLDER}/{CONFIG_FILE_NAME}"
+def make_obj_config(obj_name: str, fields_to_overwrite: dict = None) -> result:
+    if fields_to_overwrite is None:
+        fields_to_overwrite = {}
     try:
-        config = get_config(config_path)
-        if force:
-            config.remove_section(obj_name)
+        config = get_config(DEFAULT_CONFIG_FILE_PATH)
         config.add_section(obj_name)
-        config[obj_name]["obj_id"] = obj_id if obj_id is not None else f"Paste the id of {obj_name} here :)"
-        update_config(f"{DEFAULT_FOLDER}/{CONFIG_FILE_NAME}", config)
+        config[obj_name] = make_config_section(obj_name) | fields_to_overwrite
+        update_config(DEFAULT_CONFIG_FILE_PATH, config)
     except (ValueError, DuplicateSectionError) as e:
         return False, f"Could not update config file: {e!r}"
     except FileNotFoundError:
         return (
             None,
-            f"Could not find config file at {config_path!r} (try running `aliot init)`",
+            f"Could not find config file at {DEFAULT_CONFIG_FILE_PATH!r} (try running `aliot init)`",
         )
 
     return True, None
